<?php
declare(strict_types=1);

namespace Catequil\ORM;

use Doctrine\ORM\EntityManager;
use Doctrine\ORM\EntityManagerInterface;

/**
 * Class ConfigProvider
 *
 * @package Catequil\ORM
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-orm
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return [
            'dependencies' => $this->getDependencies(),
            'orm' => $this->getOrmConfig(),
        ];
    }

    public function getOrmConfig(): array
    {
        return [
            'default_entity_manager' => 'orm.default',
            'entity_managers' => [
                'orm.default' => [
                    'connection' => 'db.default',
                    'entity_paths' => [],
                ],
            ],
        ];
    }

    public function getDependencies(): array
    {
        return [
            'aliases' => [
                'em' => EntityManager::class,
                'orm' => EntityManager::class,
                EntityManagerInterface::class => EntityManager::class,
            ],
            'abstract_factories' => [
                Container\EntityManagerAbstractFactory::class,
            ],
        ];
    }
}
