<?php
declare(strict_types=1);

namespace Catequil\ORM\Container;

use Doctrine\ORM\EntityManager;
use Doctrine\ORM\EntityManagerInterface;
use Doctrine\ORM\ORMSetup;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;
use Laminas\ServiceManager\Factory\AbstractFactoryInterface;
use Psr\Container\ContainerInterface;
use Throwable;

/**
 * Class EntityManagerAbstractFactory
 *
 * @package Catequil\ORM\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-orm
 */
final class EntityManagerAbstractFactory implements AbstractFactoryInterface
{
    /**
     * Can we create a service with the given name?
     *
     * @param ContainerInterface $container
     * @param $requestedName
     * @return bool
     */
    public function canCreate(ContainerInterface $container, $requestedName): bool
    {
        return is_array($this->getEmConfig($container, $requestedName));
    }

    /**
     * Create a service with the given name.
     *
     * @param ContainerInterface $container
     * @param $requestedName
     * @param array|null $options
     * @return EntityManagerInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, ?array $options = null): EntityManagerInterface
    {
        $params = $this->getEmConfig($container, $requestedName);

        try {
            $config = ORMSetup::createAttributeMetadataConfiguration($params['entity_paths'], true);
            $connection = $container->get($params['connection']);

            return new EntityManager($connection, $config);
        } catch (Throwable $e) {
            throw new ServiceNotCreatedException('Could not create entity manager.', $e->getCode(), $e);
        }
    }

    private function getEmConfig(ContainerInterface $container, string $requestedName): ?array
    {
        /** @noinspection PhpUnhandledExceptionInspection */
        $config = $container->get('config')['orm'] ?? [];

        if ($requestedName === EntityManager::class) {
            $requestedName = $config['default_entity_manager'] ?? 'orm.default';
        }

        return $config['entity_managers'][$requestedName] ?? null;
    }
}