<?php
declare(strict_types=1);

namespace CatequilTest\ORM\Container;

use CatequilTest\ORM\AbstractTestCase;
use Doctrine\ORM\EntityManager;
use Laminas\ServiceManager\Exception\ServiceNotCreatedException;

/**
 * Class EntityManagerAbstractFactoryTest
 *
 * @package CatequilTest\ORM\Container
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/catequil-orm
 */
class EntityManagerAbstractFactoryTest extends AbstractTestCase
{
    protected static array $config = [

    ];

    public function testCanGetDefaultEntityManager(): void
    {
        $container = self::getContainer();
        /** @noinspection PhpUnhandledExceptionInspection */
        $entityManager = $container->get(EntityManager::class);

        self::assertInstanceOf(EntityManager::class, $entityManager);
        /** @noinspection PhpUnhandledExceptionInspection */
        self::assertSame($entityManager, $container->get('orm'));
    }

    public function testWillThrowExceptionForInvalidConnection(): void
    {
        self::expectException(ServiceNotCreatedException::class);

        $container = self::getContainer([
            'orm' => [
                'entity_managers' => [
                    'orm.default' => [
                        'connection' => 'db.invalid',
                    ],
                ],
            ],
        ]);

        /** @noinspection PhpUnhandledExceptionInspection */
        $container->get(EntityManager::class);
    }
}
